pub(crate) fn render_rust(
tokens: TokenStream,
preamble: &[FileComment],
) -> Result<String, RustSourceError>Expand description
Parses a complete token stream as a Rust file and formats it in-process.
pub(crate) fn render_rust(
tokens: TokenStream,
preamble: &[FileComment],
) -> Result<String, RustSourceError>Parses a complete token stream as a Rust file and formats it in-process.